@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package rendering
 
@@ -17,7 +18,7 @@ func TestCRDRender(t *testing.T) {
 	if err != nil {
 		t.Fatalf("failed to get working dir %v", err)
 	}
-	crdsPath := path.Join(path.Dir(path.Dir(wd)), "crds")
+	testCrdsPath := path.Join(wd, "testdata")
 
 	mch := &operatorsv1.MultiClusterHub{
 		ObjectMeta: metav1.ObjectMeta{
@@ -26,6 +27,16 @@ func TestCRDRender(t *testing.T) {
 		},
 	}
 
+	t.Run("New renderer", func(t *testing.T) {
+		os.Setenv(CRDsPathEnvVar, testCrdsPath)
+		defer os.Unsetenv(CRDsPathEnvVar)
+
+		_, err := NewCRDRenderer(mch)
+		if err != nil {
+			t.Errorf("NewCRDRenderer() error = %v, wantErr %v", err, nil)
+		}
+	})
+
 	t.Run("Missing env variable", func(t *testing.T) {
 		os.Unsetenv(CRDsPathEnvVar)
 
@@ -37,13 +48,24 @@ func TestCRDRender(t *testing.T) {
 	})
 
 	t.Run("Render successfully", func(t *testing.T) {
-		os.Setenv(CRDsPathEnvVar, crdsPath)
-		defer os.Unsetenv(CRDsPathEnvVar)
-
-		renderer, err := NewCRDRenderer(mch)
-		_, err = renderer.Render()
-		if err != nil {
+		renderer := &CRDRenderer{
+			directory: path.Join(testCrdsPath, "success"),
+			cr:        mch,
+		}
+		_, errs := renderer.Render()
+		if errs != nil {
 			t.Errorf("CRDRenderer.Render() error = %v, wantErr %v", err, nil)
 		}
 	})
+
+	t.Run("Render error", func(t *testing.T) {
+		renderer := &CRDRenderer{
+			directory: path.Join(testCrdsPath, "failure"),
+			cr:        mch,
+		}
+		_, errs := renderer.Render()
+		if len(errs) != 2 {
+			t.Errorf("CRDRenderer.Render() error = %v, wanted %d errors", err, 2)
+		}
+	})
 }
